==> nemoa-0.5.577-py3-none-any.whl: nemoa/math/stat.py <==
# -*- coding: utf-8 -*-
# Copyright (c) 2013-2019 Patrick Michl
#
# This file is part of nemoa, https://frootlab.github.io/nemoa
#
#  nemoa is free software: you can redistribute it and/or modify it under the
#  terms of the GNU General Public License as published by the Free Software
#  Foundation, either version 3 of the License, or (at your option) any later
#  version.
#
#  nemoa is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
#  A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#  You should have received a copy of the GNU General Public License along with
#  nemoa. If not, see <http://www.gnu.org/licenses/>.
#
"""Statistics."""

__author__ = 'Patrick Michl'
__email__ = 'frootlab@gmail.com'
__license__ = 'GPLv3'
__docformat__ = 'google'

from typing import List, Optional
from flib import catalog

#
# Define Catalog Categories
#

@catalog.category
class Association:
    """Catalog category for :term:`association measures <association measure>`.

    Attributes:
        name: Name of the association measure
        tags: List of strings, that describe the algorithm and allow it to be
            found by browsing or searching.
        classes: Optional list of model class names, that can be processed by
            the algorithm.
        plot: Name of plot class, which is used to interpret the results.
            Supported values are: None, 'Heatmap', 'Histogram', 'Scatter2D' or
            'Graph'. Default: 'Heatmap'.
        directed: Boolean value which indicates if the measure of association is
            dictected. Default: True.
        signed: Boolean value which indicates if the measure of association is
            signed. Default: True.
        normal: Boolean value which indicates if the measure of association is
            normalized. Default: False.

    """
    name: str
    tags: Optional[List[str]] = None
    classes: Optional[List[str]] = None
    plot: str = 'Heatmap'
    directed: bool = True
    signed: bool = True
    normal: bool = False

@catalog.category
class Statistic:
    """Catalog category for sample statistics.

    Sample statistics are measures of some attribute of the individual columns
    of a sample, e.g. the arithmetic mean values. For more information see [1]

    Attributes:
        name: Name of the algorithm
        tags: List of strings, that describe the algorithm and allow it to be
            found by browsing or searching
        classes: Optional list of model class names, that can be processed by
            the algorithm
        plot: Name of plot class, which is used to interpret the results.
            Supported values are: None, 'Heatmap', 'Histogram', 'Scatter2D' or
            'Graph'. The default value is 'Histogram'

    References:
        [1] https://en.wikipedia.org/wiki/Statistic

    """
    name: str
    tags: Optional[List[str]] = None
    classes: Optional[List[str]] = None
    plot: str = 'Histogram'

@catalog.category
class Sampler:
    """Catalog category for statistical samplers.

    Statistical samplers are random functions, that generate samples from a
    desired posterior distribution in Bayesian data analysis. Thereby the
    different approaches exploit properties of the underlying dependency
    structure. For more information see e.g. [1]

    Attributes:
        name: Name of the algorithm
        tags: List of strings, that describe the algorithm and allow it to be
            found by browsing or searching
        classes: Optional list of model class names, that can be processed by
            the algorithm
        plot: Name of plot class, which is used to interpret the results.
            Supported values are: None, 'Heatmap', 'Histogram', 'Scatter2D' or
            'Graph'. The default value is 'Histogram'

    References:
        [1] https://en.wikipedia.org/wiki/Gibbs_sampling

    """
    name: str
    tags: Optional[List[str]] = None
    classes: Optional[List[str]] = None
    plot: str = 'Histogram'

==> nemoa-0.5.578-py3-none-any.whl: nemoa/math/stat.py <==
# -*- coding: utf-8 -*-
# Copyright (c) 2013-2019 Patrick Michl
#
# This file is part of nemoa, https://frootlab.github.io/nemoa
#
#  nemoa is free software: you can redistribute it and/or modify it under the
#  terms of the GNU General Public License as published by the Free Software
#  Foundation, either version 3 of the License, or (at your option) any later
#  version.
#
#  nemoa is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
#  A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#  You should have received a copy of the GNU General Public License along with
#  nemoa. If not, see <http://www.gnu.org/licenses/>.
#
"""Statistics."""

__author__ = 'Patrick Michl'
__email__ = 'frootlab@gmail.com'
__license__ = 'GPLv3'
__docformat__ = 'google'

from typing import List, Optional
from flab.base import catalog

#
# Define Catalog Categories
#

@catalog.category
class Association:
    """Catalog category for :term:`association measures <association measure>`.

    Attributes:
        name: Name of the association measure
        tags: List of strings, that describe the algorithm and allow it to be
            found by browsing or searching.
        classes: Optional list of model class names, that can be processed by
            the algorithm.
        plot: Name of plot class, which is used to interpret the results.
            Supported values are: None, 'Heatmap', 'Histogram', 'Scatter2D' or
            'Graph'. Default: 'Heatmap'.
        directed: Boolean value which indicates if the measure of association is
            dictected. Default: True.
        signed: Boolean value which indicates if the measure of association is
            signed. Default: True.
        normal: Boolean value which indicates if the measure of association is
            normalized. Default: False.

    """
    name: str
    tags: Optional[List[str]] = None
    classes: Optional[List[str]] = None
    plot: str = 'Heatmap'
    directed: bool = True
    signed: bool = True
    normal: bool = False

@catalog.category
class Statistic:
    """Catalog category for sample statistics.

    Sample statistics are measures of some attribute of the individual columns
    of a sample, e.g. the arithmetic mean values. For more information see [1]

    Attributes:
        name: Name of the algorithm
        tags: List of strings, that describe the algorithm and allow it to be
            found by browsing or searching
        classes: Optional list of model class names, that can be processed by
            the algorithm
        plot: Name of plot class, which is used to interpret the results.
            Supported values are: None, 'Heatmap', 'Histogram', 'Scatter2D' or
            'Graph'. The default value is 'Histogram'

    References:
        [1] https://en.wikipedia.org/wiki/Statistic

    """
    name: str
    tags: Optional[List[str]] = None
    classes: Optional[List[str]] = None
    plot: str = 'Histogram'

@catalog.category
class Sampler:
    """Catalog category for statistical samplers.

    Statistical samplers are random functions, that generate samples from a
    desired posterior distribution in Bayesian data analysis. Thereby the
    different approaches exploit properties of the underlying dependency
    structure. For more information see e.g. [1]

    Attributes:
        name: Name of the algorithm
        tags: List of strings, that describe the algorithm and allow it to be
            found by browsing or searching
        classes: Optional list of model class names, that can be processed by
            the algorithm
        plot: Name of plot class, which is used to interpret the results.
            Supported values are: None, 'Heatmap', 'Histogram', 'Scatter2D' or
            'Graph'. The default value is 'Histogram'

    References:
        [1] https://en.wikipedia.org/wiki/Gibbs_sampling

    """
    name: str
    tags: Optional[List[str]] = None
    classes: Optional[List[str]] = None
    plot: str = 'Histogram'
